package com.skeleton.Main;

import org.jboss.seam.annotations.*;
import org.quartz.Scheduler;
import java.util.Date;
import org.quartz.JobDataMap;
import org.quartz.JobDetail;
import org.quartz.SimpleTrigger;
import org.jboss.seam.async.QuartzDispatcher;
import javax.persistence.EntityManager;
import javax.persistence.EntityManagerFactory;
import javax.persistence.Persistence;
import org.jboss.seam.log.Log;
import com.skeleton.model.TestTable;

@Name("starter")
public class Starter {

	@Logger
	private Log fLog;

	private SkeletonPipelineProcessor fSkeletonPipelineProcessor;

	public void initialise() {
		
		fSkeletonPipelineProcessor = new SkeletonPipelineProcessor();	
		fSkeletonPipelineProcessor.initialise();		
	}

	@Observer("org.jboss.seam.postInitialization")
	public void observe() {

		fLog.info("Starting Skeleton Framework");
		try {
			initialise();

			QuartzDispatcher fQuartzDispatcher = QuartzDispatcher.instance();
			Scheduler fScheduler = fQuartzDispatcher.getScheduler();

			JobDetail fJobDetail = new JobDetail("SkeletonPipeline",
					fScheduler.DEFAULT_GROUP, SkeletonPipelineJob.class);
			SimpleTrigger fSimpleTrigger = new SimpleTrigger(
					"SkeletonPipelineTrigger", fScheduler.DEFAULT_GROUP,
					new Date(), null, SimpleTrigger.REPEAT_INDEFINITELY,
					(long) 1000);

			JobDataMap fJobDataMap = fJobDetail.getJobDataMap();

			fJobDataMap.put("SkeletonPipelineProcessor",
					fSkeletonPipelineProcessor);
			fJobDataMap.put("QuartzScheduler", fScheduler);

			fScheduler.scheduleJob(fJobDetail, fSimpleTrigger);
		} catch (Exception fException) {
			fLog.error(fException.getMessage());
		}
	}
}
